#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_LOGICAL_NOTAND_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_LOGICAL_NOTAND_HPP_INCLUDED

#include <boost/simd/boolean/include/functions/simd/logical_notand.hpp>

#endif
